==========
Developers
==========

* Magdalena Rother <rother.magdalena@gmail.com>
* Kristian Rother <krother@academis.eu>
* Tomasz Puton <tomasz.puton@gmail.com>
* Pawel Piatkowski <ppiatkowski@genesilico.pl>
* Janusz M. Bujnicki <iamb@genesilico.pl>

